<template>
    <form @submit.prevent="submit">
        <div class="mb-4 relative rounded-md shadow-sm text-center">
            <label class="block text-sm font-medium leading-5 text-gray-700" for="patente">{{ $t('INGRESE SU PATENTE') }}</label>
            <input
                id="patente"
                v-model.trim="ticket.patente"
                :placeholder="$t('INGRESE SU PATENTE')"
                class="form-input block w-full mt-1 sm:text-sm sm:leading-5 patente-nueva"
                required
                type="text"
                @input="updatedPatente"
                autofocus
            />
        </div>
        <div class="mb-4 text-center">
            <button id="search"
            class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-8 rounded focus:outline-none focus:shadow-outline"
            data-style="zoom-in" type="button"
            @click="searchPatente"
            >
                {{ $t('Buscar') }}
            </button>
        </div>
        <div id="resultado" v-show="showResult">
            <ul v-show="!patente.error">
                <li><strong>Año: </strong> {{ patente.year }}</li>
                <li><strong>Marca y modelo: </strong> {{ patente.ds }}</li>
                <li><strong>Modelo: </strong>{{ patente.model }}</li>
                <li><strong>Dominio: </strong> {{ patente.domain }}</li>
            </ul>
            <span v-if="patente.error">{{ patente.error }}</span>
        </div>
        <div v-show="showEmailAndBuy">
            <div class="mb-4 relative rounded-md shadow-sm text-center" >
                <label class="block text-sm font-medium leading-5 text-gray-700" for="email">{{ $t('Email') }}</label>
                <input
                    id="email"
                    v-model="ticket.email"
                    :placeholder="$t('Email')"
                    class="form-input block w-full mt-1 sm:text-sm sm:leading-5"
                    required
                    type="email"
                />
            </div>

            <div class="mb-4 relative rounded-md shadow-sm text-center">
                <label class="block text-sm font-medium leading-5 text-gray-700" for="name">{{ $t('Nombre') }}</label>
                <input
                    id="name"
                    v-model="ticket.name"
                    :placeholder="$t('Nombre')"
                    class="form-input block w-full mt-1 sm:text-sm sm:leading-5"
                    required
                    type="text"
                />
            </div>
        </div>

        <div class="mb-4 text-center" v-show="showEmailAndBuy">
            <button id="request"
            class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-8 rounded focus:outline-none focus:shadow-outline"
            data-style="zoom-in" type="button"
            @click="solicitarPatente"
            :disabled="!ticket.email || !ticket.name || isLoading"
            >
                {{ $t('Solicitar patente') }}

                <small class="center text-white" v-if="isLoading">
                    <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        width="24px" height="30px" viewBox="0 0 24 30" style="enable-background:new 0 0 50 50; display: inline; color: white;" xml:space="preserve" >
                        <rect x="0" y="10" width="4" height="10" fill="#333" opacity="0.2">
                        <animate attributeName="opacity" attributeType="XML" values="0.2; 1; .2" begin="0s" dur="0.6s" repeatCount="indefinite" />
                        <animate attributeName="height" attributeType="XML" values="10; 20; 10" begin="0s" dur="0.6s" repeatCount="indefinite" />
                        <animate attributeName="y" attributeType="XML" values="10; 5; 10" begin="0s" dur="0.6s" repeatCount="indefinite" />
                        </rect>
                        <rect x="8" y="10" width="4" height="10" fill="#333"  opacity="0.2">
                        <animate attributeName="opacity" attributeType="XML" values="0.2; 1; .2" begin="0.15s" dur="0.6s" repeatCount="indefinite" />
                        <animate attributeName="height" attributeType="XML" values="10; 20; 10" begin="0.15s" dur="0.6s" repeatCount="indefinite" />
                        <animate attributeName="y" attributeType="XML" values="10; 5; 10" begin="0.15s" dur="0.6s" repeatCount="indefinite" />
                        </rect>
                        <rect x="16" y="10" width="4" height="10" fill="#333"  opacity="0.2">
                        <animate attributeName="opacity" attributeType="XML" values="0.2; 1; .2" begin="0.3s" dur="0.6s" repeatCount="indefinite" />
                        <animate attributeName="height" attributeType="XML" values="10; 20; 10" begin="0.3s" dur="0.6s" repeatCount="indefinite" />
                        <animate attributeName="y" attributeType="XML" values="10; 5; 10" begin="0.3s" dur="0.6s" repeatCount="indefinite" />
                        </rect>
                    </svg>
                </small>
            </button>
        </div>

    </form>
</template>

<!-- add style -->
<style>
#patente {
    width: 300px;
    height: 100px;
    margin: auto;
    font-size: 24px;
    text-align: center;
    line-height: 150px;
    border: 0px;
    border-radius: 10px;
    background-size: cover;
    background-repeat: no-repeat;
    transition: background-image 0.3s;
    background-size: 100%;
    text-transform: uppercase;

}
#patente::placeholder {
  	padding-top: -2rem !important;
    font: 0.8rem sans-serif;
}
#patente:focus {
  outline: none !important;
}


.patente-nueva {
    background-image: url('https://i.ibb.co/FHCKxK2/Neuva.png');
    color: #333;
    padding-top:0.41em !important;
    font-size: 3em !important;
    font-family: 'Rubik',sans-serif;
}

.patente-vieja {
    background-image: url('https://i.imgur.com/GMKLFJ4.png');
    color: #ffffff;
  padding-top: 0.3em !important;
  font-size: 3em !important;
  font-family: 'license_plateregular';
}
</style>

<script>
import Cookies from 'js-cookie';
export default {
    name: "search-patente",
    mounted() {
        this.getUserInfo();
    },
    metaInfo() {
        return {
            title: this.$i18n.t('Buscar Patente')
        }
    },
    data() {
        return {
            ticket: {
                email: null,
                patente: null,
                captcha: null,
                name: null
            },
            patente: {
                year: null,
                ds: null,
                model: null,
                domain: null,
                error: null
            },
            user: null,
            showResult: false,
            showEmailAndBuy: false,
            showSubmmited: true,
            isLoading: false
        }
    },
    methods: {
        getUserInfo(){
            const self = this;
            axios2.get('api/auth/user').then(function (response) {
                console.log(response.data)
                self.user = response.data;
                self.ticket.email = response.data.email;
                self.ticket.name = response.data.name;
            }).catch(function () {
                console.log("Not Logged in")
            });
        },
        searchPatente(){
            let self = this;

            self.showResult = false;
            window.parent.postMessage({"showResult":self.showResult}, "*")
            self.showEmailAndBuy = false;
            let patente = this.ticket.patente;
            console.log("Buscando patente: "+patente)
            let url = 'api/lang/patente/'+patente;
            axios.get(url)
            .then(function(response) {
                console.log(response.data)
                let data = response.data
                self.showResult = true;
                self.showEmailAndBuy = true;
                window.parent.postMessage({"showResult":12}, "https://registroautomotores.com")
                if (data.p_aut_fmm_ds !== null) {
                    self.patente.year = data.p_aut_anio;
                    self.patente.ds = data.p_aut_fmm_ds;
                    self.patente.model = data.p_aut_modelo.toLocaleString()
                    self.patente.domain = data.dominio
                    self.patente.error = null

                } else {
                    self.patente.error = "No se encontraron datos para la patente ingresada."
                }
            })
                .catch(function(error) {
                    self.patente.error = "No se encontraron datos para la patente ingresada"
            });
        },
        updatedPatente(){

            let patente = this.ticket.patente;
            let patenteDesign = this.getPatenteDesign(patente);

            document.getElementById("patente").classList.remove("patente-vieja");
            document.getElementById("patente").classList.remove("patente-nueva");
            document.getElementById("patente").classList.add(patenteDesign);

        },
        getPatenteDesign(numeroPatente) {
            var plate = numeroPatente.toUpperCase().trim(),
            reLegacyPlate = /^([A-Z]{3}|[0-9]{3})/,
            inputType = (reLegacyPlate.test(plate) ? 'patente-vieja' : 'patente-nueva');
            return inputType;
        },
        solicitarPatente()
        {
            this.isLoading = true;
            this.ticket.patente = this.ticket.patente.toUpperCase().trim();
            console.log("Solicitando patente...")

            let self = this;
            let patente = self.ticket.patente;
            let email = self.ticket.email;

            let user_id = null;

            axios.post("/api/lang/isregistered", {
                email: email
            }).then(response => {
                let data = response.data
                if (response.data.registered){
                    console.log("User registered with Id:", response.data.registered)
                    self.submitTicket(response.data.registered, false)
                }
                else {
                    console.log("User is not registered")
                    let pswd = Math.random().toString(36).slice();
                    // remove the dot
                    pswd = pswd.replace(".", "");
                    let tmpuser = {
                        name: self.ticket.name,
                        email: self.ticket.email,
                        password: pswd,
                        password_confirmation: pswd,
                        captcha: null
                    }

                    axios.post('api/auth/register?auto', tmpuser).then(function (response) {
                        console.log(response.data)
                        self.$notify({
                            title: self.$i18n.t('Success').toString(),
                            text: self.$i18n.t('Account created successfully').toString(),
                            type: 'success'
                        })
                        self.$store.commit('login', response.data);

                        self.submitTicket(response.data.user.id, true)
                        // if (response.data.user.role.dashboard_access) {
                        //     self.$router.push('/dashboard/home');
                        // } else {
                        //     self.$router.push('/tickets/list');
                        // }
                    }).catch(function () {
                        alert("Error creando usuario")
                        this.isLoading = false;
                    });
                }
            })
        },
        submitTicket(userId, newUser){
            console.log("Submiting ticmet for user", userId)
            let self = this;
            console.log(self.ticket)
            console.log(self.patente)

            let payload = {
                user: userId,
                ticket: self.ticket,
                patente: self.patente
            }

            console.log(payload)

            axios.post("api/lang/ticket", payload).then(function (response) {
                console.log(response.data)
                self.showSubmmited = true;
                self.$notify({
                    title: self.$i18n.t('Success').toString(),
                    text: self.$i18n.t('Ticket creado exitosamente').toString(),
                    type: 'success'
                });
                if(newUser){
                    self.$router.push('/tickets/list?newuser=true');
                    window.parent.postMessage({"ticket_sent":"newuser"}, "https://registroautomotores.com")
                } else {
                    self.$router.push('/tickets/list');
                    window.parent.postMessage({"ticket_sent":"existing"}, "https://registroautomotores.com")
                }
            }).catch(function () {
                window.parent.postMessage({"error":"creating_ticket"}, "https://registroautomotores.com")
                this.isLoading = false;
            });

        }
    }
}
</script>
